@@ -74,6 +74,9 @@ class MessagesModel : public QAbstractListModel
     Tp::TextChannelPtr textChannel() const;
     void setTextChannel(const Tp::TextChannelPtr &channel);
 
+    Tp::AccountPtr account() const;
+    void setAccount(const Tp::AccountPtr &account);
+
     bool isVisibleToUser() const;
     void setVisibleToUser(bool visible);
 
@@ -88,6 +91,7 @@ class MessagesModel : public QAbstractListModel
   Q_SIGNALS:
     void visibleToUserChanged(bool visible);
     void unreadCountChanged(int unreadMesssagesCount);
+    void lastMessageChanged();
 
   public Q_SLOTS:
     void sendNewMessage(const QString &message);
